@@ -143,7 +143,7 @@ class Membership extends Base
 
 		//set some vars for view
 		$this->view->title  = Lang::txt('Invite Members: ' . $this->view->group->get('description'));
-		$this->view->msg    = trim(Request::getVar('msg', ''));
+		$this->view->msg    = trim(Request::getVar('msg', $this->config->get('invite_message', '')));
 		$this->view->return = trim(Request::getVar('return', ''));
 
 		//display view
