@@ -574,6 +574,7 @@ class Project extends Model
 				$this->params->set('access-manager-project', true); // May edit project properties
 				$this->params->set('access-content-project', true); // May add/edit/delete all content
 				$this->params->set('access-owner-project', true);
+				$this->params->set('access-componentmanager-project', true);
 			}
 			return;
 		}
@@ -1285,7 +1286,8 @@ class Project extends Model
 			break;
 
 			case 'thumb':
-				$link = $this->_base . '&controller=media&media=thumb';
+				//$link = $this->_base . '&controller=media&media=thumb';
+				$link = $this->picture();
 			break;
 
 			case 'view':
@@ -1304,4 +1306,78 @@ class Project extends Model
 
 		return $link;
 	}
+
+	/**
+	 * Generate and return path to a picture for the project
+	 *
+	 * @param   string   $size      Thumbnail (thumb) or full size (master)?
+	 * @param   boolean  $realpath  Return the actual file path? When FALSE, it returns a link to /files/{hash}
+	 * @return  string
+	 */
+	public function picture($size = 'thumb', $realpath = false)
+	{
+		$src  = '';
+		$path = PATH_APP . DS . trim($this->config()->get('imagepath', '/site/projects'), DS) . DS . $this->get('alias') . DS . 'images';
+
+		if ($size == 'thumb')
+		{
+			// Does a thumb exist?
+			if (file_exists($path . DS . 'thumb.png'))
+			{
+				$src = $path . DS . 'thumb.png';
+			}
+
+			// No thumb. Try to create it...
+			if (!$src && $this->get('picture'))
+			{
+				$thumb = \Components\Projects\Helpers\Html::createThumbName($this->get('picture'));
+
+				if ($thumb && file_exists($path . DS . $thumb))
+				{
+					$src = $path . DS . $thumb;
+				}
+			}
+		}
+		else
+		{
+			// Get the picture if set
+			if ($this->get('picture') && is_file($path . DS . $this->get('picture')))
+			{
+				$src = $path . DS . $this->get('picture');
+			}
+		}
+
+		// Still no file? Let's use the default
+		if (!$src)
+		{
+			$deprecated = array(
+				'components/com_projects/site/assets/img/project.png',
+				'components/com_projects/assets/img/project.png',
+				'components/com_projects/site/assets/img/projects-large.gif',
+				'components/com_projects/assets/img/projects-large.gif'
+			);
+
+			$path = trim($this->config()->get('defaultpic', 'components/com_projects/site/assets/img/project.png'), DS);
+
+			if (in_array($path, $deprecated))
+			{
+				$path = 'components/com_projects/site/assets/img/project.png';
+				$rootPath = PATH_CORE;
+			}
+			else
+			{
+				$rootPath = PATH_APP;
+			}
+
+			$src = $rootPath . DS . $path;
+		}
+
+		// Gnerate a file link
+		if (!$realpath)
+		{
+			$src = with(new \Hubzero\Content\Moderator($src, 'public'))->getUrl();
+		}
+
+		return $src;
+	}
 }
