@@ -44,17 +44,17 @@ use ZipArchive;
 class File extends Base
 {
 	/**
-	* Attachment type name
-	*
-	* @var  string
-	*/
+	 * Attachment type name
+	 *
+	 * @var  string
+	 */
 	protected $_name = 'file';
 
 	/**
-	* Git handler
-	*
-	* @var  object
-	*/
+	 * Git handler
+	 *
+	 * @var  object
+	 */
 	protected $_git = null;
 
 	/**
@@ -142,6 +142,7 @@ class File extends Base
 		$bundleName           = $versionParams->get('element' . $elementId . 'bundlename', $configs->title);
 		$configs->bundleTitle = $bundleName ? $bundleName : $configs->title;
 		$configs->bundleName  = $bundleName ? $bundleName . '.zip' : 'bundle.zip';
+		$configs->bundleOverwrite = $versionParams->get('bundleOverwrite', false);
 
 		// Allow rename?
 		$configs->allowRename = false;
@@ -193,7 +194,7 @@ class File extends Base
 		// Add inside bundles
 		if ($configs->multiZip == 1 && $attachments && count($attachments) > 1)
 		{
-			$filePath = $this->bundle($attachments, $configs, false);
+			$filePath = $this->bundle($attachments, $configs, $configs->bundleOverwrite);
 			$bPath    = $configs->pubBase . DS . 'bundles';
 			if (is_file($filePath))
 			{
@@ -411,7 +412,7 @@ class File extends Base
 				$html .= ' <span class="edititem">';
 				$html .= '<a href="index.php?option=com_publications&controller=items&task=editcontent&id=' . $pub->get('id') . '&el=' . $elementId . '&v=' . $pub->get('version_number') . '">';
 				$html .= Lang::txt('COM_PUBLICATIONS_EDIT');
-				$hmtl .= '</a>';
+				$html .= '</a>';
 				$html .= '</span>';
 			}
 			$html .= '</span>';
@@ -671,13 +672,11 @@ class File extends Base
 
 				// Create hash file
 				$hfile =  $copyTo . '.hash';
-				if (!is_file($hfile))
-				{
-					$handle = fopen($hfile, 'w');
-					fwrite($handle, $md5hash);
-					fclose($handle);
-					chmod($hfile, 0644);
-				}
+				$handle = fopen($hfile, 'w');
+				fwrite($handle, $md5hash);
+				fclose($handle);
+				@chmod($hfile, 0644);
+
 				$pAttach->store();
 
 				// Produce thumbnail (if applicable)
@@ -1280,13 +1279,11 @@ class File extends Base
 
 			// Create hash file
 			$hfile = $copyTo . '.hash';
-			if (!is_file($hfile))
-			{
-				$handle = fopen($hfile, 'w');
-				fwrite($handle, $md5hash);
-				fclose($handle);
-				chmod($hfile, 0644);
-			}
+			$handle = fopen($hfile, 'w');
+			fwrite($handle, $md5hash);
+			fclose($handle);
+			@chmod($hfile, 0644);
+
 			$objPA->store();
 
 			// Produce thumbnail (if applicable)
